@@ -1,16 +1,13 @@
 Shaman.StineT <-
-function(x,p,h,correct)
+function(x,p,h)
 {
 x <- as.matrix(x)
 n <- nrow(x)
 b <- LSMT(x,p)$coef
 bc <- c(StineT(b,n,p),b[p+1],b[p+2])
-
-    if( correct == "kilian")
+ 
     bc <- adjust(b,bc,p)
-    if( correct == "ssf")
-    bc <- adjust2(bc,p)
-
+ 
 bc[(p+1):(p+2),] <- RE.LSMT(x,p,bc)
  
 e <- RESIDT(x,bc)
@@ -19,4 +16,3 @@ if(h > 0)
 f <- ART.Fore(x,bc,h)
 return(list(coef=bc,resid=e,forecast=f))
 }
-
